<template>
  <div class="container py-5">
    <h4 class="text-end mb-3">{{ t('advertise_stats.title') }}</h4>

    <div class="card border-0 shadow-sm p-4" v-if="data.loaded">
      <div class="d-flex justify-content-between align-items-center mb-3">
        <span class="fw-bold">{{ t('advertise_stats.total_views') }}:</span>
        <span class="text-danger fw-bold fs-5">{{ data.total }}</span>
      </div>

      <div style="height: 400px;">
        <LineChart :chartData="data.chartData" :chartOptions="data.chartOptions" />
      </div>
    </div>

    <div v-else class="text-center text-muted py-5">
      {{ t('advertise_stats.loading') }}
    </div>
  </div>
</template>

<script setup>
import LineChart from '~/components/LineChart.vue'
import {ref, onMounted, reactive} from 'vue'
import { useRoute } from 'vue-router'
import { useCookie } from '#imports'
import { useI18n } from 'vue-i18n'

const { t } = useI18n()
const route = useRoute()
const { $api } = useNuxtApp()
const token = useCookie('token');

const data = reactive({
  total: 0,
  loaded: false,
  chartData: null,
  chartOptions: {}
})

const getStats = async () => {
  data.loaded = false;
  await $api.post('/user/advertise/stats', {
    id: route.params.id
  }, {
    headers: {
      Authorization: `Bearer ${token.value}`
    }
  }).then((value) => {
    const stats = value.data.data;

    data.chartData = {
      labels: stats.labels,
      datasets: [
        {
          label: t('advertise_stats.total_views'),
          data: stats.values,
          borderColor: '#dc3545',
          backgroundColor: 'rgba(220, 53, 69, 0.1)',
          tension: 0.4,
          fill: true,
          pointRadius: 4,
          pointHoverRadius: 6
        }
      ]
    }

    data.chartOptions = {
      responsive: true,
      maintainAspectRatio: false,
      plugins: {
        legend: { position: 'bottom' },
        title: { display: true, text: t('advertise_stats.chart_title') }
      },
      scales: {
        x: { grid: { display: false } },
        y: { beginAtZero: true }
      }
    }

    data.total = stats.total;

    data.loaded = true;
  });
}

onMounted(() => {
  getStats();
})
</script>

